Documentation
¶
Overview ¶
Package dinofyi provides a Go client for the DinoFYI API (dinofyi.com).
DinoFYI — zero dependencies, no authentication required.
Usage:
client := dinofyi.NewClient()
result, err := client.Search("query")
Index ¶
- Constants
- type Client
- func (c *Client) Classification(slug string) (map[string]interface{}, error)
- func (c *Client) Classifications() (map[string]interface{}, error)
- func (c *Client) Comparison(slug string) (map[string]interface{}, error)
- func (c *Client) Comparisons() (map[string]interface{}, error)
- func (c *Client) Countries() (map[string]interface{}, error)
- func (c *Client) Country(slug string) (map[string]interface{}, error)
- func (c *Client) Dinosaur(slug string) (map[string]interface{}, error)
- func (c *Client) Dinosaurs() (map[string]interface{}, error)
- func (c *Client) Faq(slug string) (map[string]interface{}, error)
- func (c *Client) Faqs() (map[string]interface{}, error)
- func (c *Client) Glossary() (map[string]interface{}, error)
- func (c *Client) GlossaryCategories() (map[string]interface{}, error)
- func (c *Client) GlossaryCategory(slug string) (map[string]interface{}, error)
- func (c *Client) Guide(slug string) (map[string]interface{}, error)
- func (c *Client) GuideSeries() (map[string]interface{}, error)
- func (c *Client) GuideSery(slug string) (map[string]interface{}, error)
- func (c *Client) Guides() (map[string]interface{}, error)
- func (c *Client) Period(slug string) (map[string]interface{}, error)
- func (c *Client) Periods() (map[string]interface{}, error)
- func (c *Client) Search(query string) (map[string]interface{}, error)
- func (c *Client) Site(slug string) (map[string]interface{}, error)
- func (c *Client) Sites() (map[string]interface{}, error)
- func (c *Client) Term(slug string) (map[string]interface{}, error)
Constants ¶
const DefaultBaseURL = "https://dinofyi.com"
DefaultBaseURL is the default API base URL.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is a DinoFYI API client.
func (*Client) Classification ¶
Classification returns details for a classification by slug.
func (*Client) Classifications ¶
Classifications returns a list of classifications.
func (*Client) Comparison ¶
Comparison returns details for a comparison by slug.
func (*Client) Comparisons ¶
Comparisons returns a list of comparisons.
func (*Client) GlossaryCategories ¶
GlossaryCategories returns a list of glossary categories.
func (*Client) GlossaryCategory ¶
GlossaryCategory returns details for a glossary category by slug.
func (*Client) GuideSeries ¶
GuideSeries returns a list of guide series.
Click to show internal directories.
Click to hide internal directories.